/*************************************************************************\
* Copyright (c) 2002 The University of Chicago, as Operator of Argonne
* National Laboratory.
* Copyright (c) 2002 The Regents of the University of California, as
* Operator of Los Alamos National Laboratory.
* This file is distributed subject to a Software License Agreement found
* in the file LICENSE that is included with this distribution. 
\*************************************************************************/
// Main include file for SGA

#include "sgaVersion.h"

// The following must be 1024 or less for WIN32
#define FIXED_MSG_SIZE 1024

#ifdef WIN32
// Eliminate warnings about access to the protected areas of CBlock
// (This warning seems incorrect)
# pragma warning (disable:4243)
# define DIR_DELIMITER_CHAR '\\'
# define DIR_DELIMITER_STRING "\\"
// Hummingbird extra functions including lprintf
//   Needs to be included after Intrinsic.h for Exceed 5
# include <stdio.h>
# include <X11/Intrinsic.h>
# include <X11/XlibXtra.h>
// The following is done in Exceed 6 but not in Exceed 5
//   Need it to define printf as lprintf for Windows
//   (as opposed to Console) apps */
# ifdef _WINDOWS
#  ifndef printf
#   define printf lprintf
#  endif    
# endif    
#else // #ifdef WIN32
// WIN32 does not have unistd.h
# define DIR_DELIMITER_CHAR '/'
# define DIR_DELIMITER_STRING "/"
# include <stdio.h>
# include <unistd.h>
# include <limits.h>
#endif // #ifdef WIN32

#include <sys/stat.h>
#include <sys/types.h>
//#include <sys/utsname.h>
#include <stdlib.h>
#include <stdarg.h>
#include <string.h>

// PATH_MAX
#ifdef WIN32
// Is in stdlib.h for WIN32
#define PATH_MAX _MAX_PATH
#endif

// Unreferenced
#ifdef __cplusplus
#ifdef CYGWIN32
// Get warning if it is defined as (x), no warning this way
#define UNREFERENCED(x)
#else
#define UNREFERENCED(x) (x=x)
#endif
#else
#define UNREFERENCED(x)
#endif

#include <Xm/Xm.h>

#include <tsDLList.h>

#define MAX(x,y) (((x)>=(y))?(x):(y))
#define MIN(x,y) (((x)<=(y))?(x):(y))

// Function prototypes

int errMsg(const char *fmt, ...);
void print(const char *fmt, ...);
void changeDisplayWindow(int type);
Widget createLabelBox(Widget parent, char *widgetName, char *label,
  int nCols, char *value, XtCallbackProc callback, XtPointer clientData,
  Widget *wTextField);
void disposalMethodSet(int buttonId);
void drawingAreaCB(Widget w, XtPointer clientData, XtPointer callData);

// Global variables

// EXTERN will be defined as blank where the storage is to be allocated
// Otherwise they are declared to be extern
#ifndef EXTERN
#define EXTERN extern
#endif

class CImage;
class CBlock;

EXTERN int (*errHandler)(const char *fmt, ...);
EXTERN Display *display;
EXTERN int screen;
EXTERN int nplanes;
EXTERN Screen *screenptr;

EXTERN Widget textSW,textArea,drawingSW,drawingArea,listArea;
EXTERN Widget defaultOptionArea,globalOptionArea,imageOptionArea,commentOptionArea;
EXTERN Widget transparentColorBtn,interlaceBtn,localColorTableBtn;
EXTERN Widget applyToAllImagesBtn;
EXTERN Widget transparentIndexEntry,delayTimeEntry,leftOffsetEntry,topOffsetEntry;
EXTERN Widget logicalScreenWidthEntry,logicalScreenHeightEntry,bgColorIndexEntry;
EXTERN Widget disposalMethodMenu;
EXTERN Widget commentText,commentApplyBtn;
EXTERN Widget colorTableS,colorButtons[256];
EXTERN Widget colorTableIndexEntry,colorTableOldSample,colorTableNewSample;
EXTERN Widget colorTableRedEntry,colorTableGreenEntry,colorTableBlueEntry;
EXTERN Widget colorTableRedScale,colorTableGreenScale,colorTableBlueScale;
EXTERN int currentColorTableIndex;
EXTERN CImage *currentDrawingImage;
EXTERN CBlock *selectedBlock;

#define MAXARGS 30
EXTERN Arg args[MAXARGS];
EXTERN Cardinal nargs;

EXTERN int bgMode,dataMode;
