/*************************************************************************\
* Copyright (c) 2002 The University of Chicago, as Operator of Argonne
* National Laboratory.
* Copyright (c) 2002 The Regents of the University of California, as
* Operator of Los Alamos National Laboratory.
* This file is distributed subject to a Software License Agreement found
* in the file LICENSE that is included with this distribution. 
\*************************************************************************/
// Global utilities for SGA

#include <Xm/Label.h>
#include <Xm/RowColumn.h>
#include <Xm/TextF.h>

#include "sga.h"

/**************************** errMsg **************************************/
int errMsg(const char *fmt, ...)
{
    va_list vargs;
    static char lstring[FIXED_MSG_SIZE];

    if(errHandler) {
    
	va_start(vargs,fmt);
	(void)vsprintf(lstring,fmt,vargs);
	va_end(vargs);
    
	if(lstring[0] != '\0') {
	    (*errHandler)(lstring);
	}
    }
    return 0;
}
/**************************** createLabelBox ******************************/
Widget createLabelBox(Widget parent, char *widgetName, char *label,
  int nCols, char *value, XtCallbackProc callback, XtPointer clientData,
  Widget *wTextField)
{
    Widget w0,w1;
    XmString clabel=XmStringCreateLtoR(label,XmSTRING_DEFAULT_CHARSET);
    int len;
    char name[64];
    
  // Create container
    nargs=0;
    XtSetArg(args[nargs],XmNorientation,XmHORIZONTAL); nargs++;
    w0=XmCreateRowColumn(parent,widgetName,args,nargs);
    XtManageChild(w0);
  // Create label
    sprintf(name,"%sLabel",widgetName);
    nargs=0;
    XtSetArg(args[nargs],XmNlabelString,clabel); nargs++;
    w1=XmCreateLabel(w0,name,args,nargs);
    XmStringFree(clabel);
    XtManageChild(w1);
  // Create text box
    sprintf(name,"%sTextField",widgetName);
    len=strlen(value);
    nargs=0;
    XtSetArg(args[nargs],XmNcolumns,nCols); nargs++;
    XtSetArg(args[nargs],XmNmaxLength,nCols); nargs++;
    XtSetArg(args[nargs],XmNcursorPosition,len); nargs++;
    XtSetArg(args[nargs],XmNvalue,value); nargs++;
    *wTextField=XmCreateTextField(w0,name,args,nargs);
    XtManageChild(*wTextField);
    XtAddCallback(*wTextField,XmNactivateCallback,callback,clientData);
  // Return
    return(w0);
}
